@@ -10,7 +10,7 @@
                'stockholm', 'intelligenetics', 'table', 'array','transfac')
 
 # File output formats supported
-.FORMATS = c('eps', 'png', 'pdf', 'jpeg', 'svg')
+.FORMATS = c('eps', 'png', 'pdf', 'jpeg', 'svg', 'logodata', 'png_print')
 
 # Different sequence types that can be used 
 .SEQTYPE = c('protein', 'rna', 'dna')
@@ -89,18 +89,71 @@
   }
 }
 
+
+# Make EPS more optimal, and useable by PostScriptTrace
+.ps2ps <- function (file.in, file.out) {
+  gsexe <- Sys.getenv("R_GSCMD")
+  if (.Platform$OS.type == "windows") {
+    if (!nzchar(gsexe)) 
+      gsexe <- Sys.getenv("GSC")
+    if (is.null(gsexe) || !nzchar(gsexe)) {
+      poss <- Sys.which(c("gswin64c.exe", "gswin32c.exe"))
+      poss <- poss[nzchar(poss)]
+      gsexe <- if (length(poss)) 
+        poss
+      else "gswin32c.exe"
+    }
+    else if (grepl(" ", gsexe, fixed = TRUE)) 
+      gsexe <- shortPathName(gsexe)
+    
+  }
+  else {
+    if (is.null(gsexe) || !nzchar(gsexe)) {
+      gsexe <- "gs"
+      rc <- system(paste(shQuote(gsexe), "-help > /dev/null"))
+      if (rc != 0) 
+        stop("sorry, 'gs' cannot be found")
+    }
+  }
+  
+  file.out = suppressWarnings( normalizePath(file.out) )
+  cmd <- paste(gsexe, " -q -sDEVICE=ps2write -sstdout=%stderr -sOutputFile=", 
+               file.out, " -dNOPAUSE -dBATCH -P- -dSAFER ", normalizePath(file.in), 
+               sep = "")
+  ret <- switch(.Platform$OS.type, unix = system(cmd), windows = system(cmd, invisible = TRUE))
+  if (ret != 0) stop(gettextf("status %d in running command '%s'", ret, cmd), domain = NA)
+  
+  return(cmd)
+}
+
+# plotlogo <- function(file){
+#   if(!file.exists(file)){
+#     writeLines(sprintf('File "%s" does not exist!', file))
+#     return(1)
+#   }
+#   data = readJPEG(file)
+#   plot.new()
+#   lim = par()$usr
+#   rasterImage(data, lim[1], lim[3], lim[2], lim[4])
+# }
+
 #' Display a sequence logo as an R plot
 #'
-#' This function will display a sequence logo of an already generated jpeg sequence logo. 
+#' This function will display a sequence logo of an already generated eps sequence logo. 
 #'
-#' @param file path to the jpeg image of the sequence logo
+#' @param file path to the eps formatted file of the sequence logo
+#' 
+#' 
+#' @importFrom grImport PostScriptTrace
+#' @importFrom grImport grid.picture
+#' @importFrom grImport readPicture
+#' @importFrom grid grid.newpage
 #' 
 #' @export
-#' @importFrom jpeg readJPEG
-#' @import raster
+#' 
 #' @examples
-#' # Get path to an example jpeg sequence logo
-#' fpath = system.file("extdata", "example_logo.jpeg", package="RWebLogo")
+#' # Get path to an example eps sequence logo
+#' fpath = system.file("extdata", "example_logo.eps", package="RWebLogo")
 #' # Plot it!
 #' plotlogo(fpath)
 plotlogo <- function(file){
@@ -108,10 +161,19 @@ plotlogo <- function(file){
     writeLines(sprintf('File "%s" does not exist!', file))
     return(1)
   }
-  data = readJPEG(file)
-  plot.new()
-  lim = par()$usr
-  rasterImage(data, lim[1], lim[3], lim[2], lim[4])
+  if(!grepl('.eps$', basename(file))){
+    writeLines(sprintf('The file "%s" must be eps format to plot. To save your logo as in eps format, set the "format" option to "eps" in the weblogo call', file))
+    return(1)
+  }
+  
+  filenew = tempfile(pattern = 'filenew')
+  newps = .ps2ps(file, filenew)
+  
+  outfile = tempfile(pattern = 'outfile')
+  PostScriptTrace(file = filenew, outfilename = outfile)
+  pic = readPicture(outfile)
+  grid.newpage()
+  grid.picture(pic)
 }
 
 #' Plot a sequence logo
@@ -122,7 +184,7 @@ plotlogo <- function(file){
 #' @param file.in A file containing your sequence alignment in one of the following formats: clustal, fasta, plain, msf, genbank, nbrf, nexus, phylip, stockholm, intelligenetics, table, array, transfac. This file is only to be provided if you are not inputting data with 'seqs'. To set your data format, see the \code{datatype} option.
 #' @param open Open the generated logo file? (default: TRUE).
 #' @param verbose Write status messages to the R console? (default: TRUE).
-#' @param plot Plot the resulting logo as an R plot? Note: in order for this to work, the format option must be set to \code{jpeg} (default: FALSE).
+#' @param plot Plot the resulting logo as an R plot? Note: in order for this to work, the format option must be set to \code{eps} (default: FALSE).
 #' @param return.cmd Logical indicating if RWebLogo should return the WebLogo command generated (default: FALSE).
 #' @param datatype Type of multiple sequence alignment or position weight matrix file: ('clustal', 'fasta','plain', 'msf', 'genbank', 'nbrf', 'nexus', 'phylip', 'stockholm', 'intelligenetics', 'table', 'array', 'transfac'). You usually don't need to specify this, as weblogo will try figure out the format of your file.
 #' @param file.out Output file. For example, /path/to/dir/mylogo.pdf. By default this is your working directory + RWebLogo. + selected \code{format}.
@@ -159,8 +221,11 @@ plotlogo <- function(file){
 #' @param box Draw boxes around symbols? (default: FALSE).
 #' @param resolution Bitmap resolution in dots per inch (DPI). Low resolution bitmaps with DPI<300 are antialiased  (default: 300 DPI).
 #' @param scale.width Scale the visible stack width by the fraction of symbols in the column?  i.e. columns with many gaps of unknowns are narrow (default: TRUE).
+#' 
 #' @export
+#' 
 #' @import findpython
+#' 
 #' @examples
 #' # Make a sequence logo using an external alignment file format 
 #' # In this example we'll use the EMBOSS alignment format or msf
@@ -179,9 +244,9 @@ plotlogo <- function(file){
 #' # You can change the axis labels like this
 #' weblogo(seqs=aln, xlabel='My x-axis', ylabel='Awesome bits')
 #' # Lets try plot a web logo to the R graphics device
-#' weblogo(seqs=aln, plot=TRUE, open=FALSE, format='jpeg', resolution=600)
+#' weblogo(seqs=aln, plot=TRUE, open=FALSE)
 #' # You get the idea! See ?weblogo for more awesome options! 
-#' # See ?plotlogo for more information on plotting jpeg sequence logos to the R graphics device!
+#' # See ?plotlogo for more information on plotting eps sequence logos to the R graphics device!
 weblogo = function(seqs, file.in,
                 open=TRUE, verbose=TRUE, plot=F, return.cmd=F,
                 datatype='plain',
@@ -205,7 +270,12 @@ weblogo = function(seqs, file.in,
                 ){
   
   
-  if(!can_find_python_cmd(minimum_version='2.6')){
+  if(plot){
+    format = 'eps'
+    open = F
+  }
+  
+  if(!can_find_python_cmd(minimum_version='2.6', required_modules='numpy' )){
     writeLines('Please install and add Python (>=2.6) to your path')
     return(1)
   }
@@ -241,7 +311,7 @@ weblogo = function(seqs, file.in,
     stop(sprintf('The input file %s does not exist, please use a valid input file!', file.in))
   }
   
-  #'/Users/omarwagih/Development/RWebLogo/inst/extdata/weblogo-3.3/weblogo'
+  # /Users/omarwagih/Development/RWebLogo/inst/extdata/weblogo-3.3/weblogo'
   exec = file.path( system.file("extdata", "weblogo-3.3", package="RWebLogo"), 'weblogo')
   z = c(exec,
         sprintf('< %s > %s', file.in, file.out))
@@ -258,7 +328,6 @@ weblogo = function(seqs, file.in,
   # Logo Data Options:
   ##################################################################### 
   
- 
   if(!missing(sequence.type)){
     .check(sequence.type, .SEQTYPE)
     z = .cmd.add(z, '--sequence-type', sequence.type, 'character')
@@ -269,7 +338,7 @@ weblogo = function(seqs, file.in,
     alphabet = toupper( unique(strsplit(alphabet, '')[[1]]) )
     # Find number of letters  
     nl = sum(grepl(pattern='[A-Za-z]', alphabet))
-    if(nl == 0) stop('Alphabet must have at least one alphabet letter from A-Z')
+    if(nl == 0) stop('Alphabet must have at least one letter from A-Z')
     if(length(alphabet) < 2) stop('Alphabet must have at least two letters')
     
     alphabet = paste0(alphabet, collapse='')
@@ -419,8 +488,8 @@ weblogo = function(seqs, file.in,
   }
   
   if(plot){
-    if(format != 'jpeg')
-      stop("Format must be set  to 'jpeg' to plot!")
+    if(format != 'eps')
+      stop("Format must be set to 'eps' to plot!")
     plotlogo(file.out)
   }
   
